Rails.application.routes.draw do
  # Define your application routes per the DSL in https://guides.rubyonrails.org/routing.html

  # Reveal health status on /up that returns 200 if the app boots with no exceptions, otherwise 500.
  # Can be used by load balancers and uptime monitors to verify that the app is live.
  get "up" => "rails/health#show", as: :rails_health_check

  # Defines the root path route ("/")
  root "contests#index"

  resources :contests do
    resources :completions
    resources :contestants
    resources :puzzles
    resources :messages, only: :destroy do
      get "convert", to: "messages#convert"
    end
    get "import", to: "contestants#import"
    post "import", to: "contestants#upload_csv"
    get "import/:id", to: "contestants#convert_csv"
    post "import/:id", to: "contestants#finalize_import"
  end
  resources :passwords, param: :token
  resource :session
  resources :users

  options "connect", to: "messages#cors_preflight_check"
  options "message", to: "messages#cors_preflight_check"
  post "connect", to: "messages#connect"
  post "message", to: "messages#create"

  get "public/:id", to: "contests#scoreboard"
end
